Clojure only.

pg.execute-params

A dedicated namespace to build an instance of the ExecuteParams class from a Clojure map.

A dedicated namespace to build an instance of the
`ExecuteParams` class from a Clojure map.
raw docstring

->execute-paramsclj

(->execute-params opt)

Make an instance of ExecuteParams from a Clojure map.

Make an instance of ExecuteParams from a Clojure map.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries